from __future__ import annotations

from .tool import main

if __name__ == '__main__':
    main()
